/***************************************************************************************************************/
/* HEADER FILE FOR THE ENVIRONMENT.						
/*	Dated : Dec 9th 2005						Author: Elias Abou Zeid, e_abouze@ece.concordia.ca
/*											
/*
/*Notes and Acknowledgements:					
/**************************************************************************************************************/
#ifndef ENVIRONMENT_H
#define ENVIRONMENT_H

#include <windows.h>	


# define FLOOR_SIZE 200.0 //floor size

//window size
#define  SIZE		1000.0

//Projection related
#define NEAR_Z 1.0
#define FAR_Z 1000.0	// For the frustum size.

#define PI 3.1415926535897932384626433832795

// View Volume related
//#define FIRSTVIEWFOVY  5.0
#define FIRSTVIEWFOVY  60
//#define FIRSTFVIEWVOL 0.07 //keep track of default values for first person view.
#define FIRSTFVIEWVOL 20 //keep track of default values for first person view.
#define FOVY  60
#define FVIEWVOL 20.0 //keep track of default values for third person view.
 
//Material color property, ambiant and diffuse light intensity
# define HIGH		1.0  
# define LOW        0.5

#define  HDAY       30000 //half day time in msec (30 sec)

//size related
#define FLOOR_LEVEL -2.5 //floor level
//#define FLOOR_LEVEL 0 //-2.5 //floor level

enum Projection {PERSPECTIVE, ORTHOGRAPHIC}; 

enum DayTime {DAY, NIGHT};  //DAY (no light), NIGHT (controlabale lights)

enum Weather {SHINY_DAY, FOGY_DAY};  //if it is a shiny or fogy day

enum Camera {FIRST_PERSON, THIRD_PERSON}; //camera

typedef struct{
	LPCSTR filename;
	bool mute;
	float duration;
} Sound;

typedef struct {
	Projection projection;
	DayTime day;
	Weather weather;
	Camera camera;
	GLfloat amdif; //ambiant diffuse light intensity
	bool IsShiny; //toggle between shiny non-shiny material
	DWORD timeday; // start time of a day 
	DWORD lastTickCount;
} Environment; 



void drawSphere(float fRadius, GLint slices, GLint rings);
							// Used to generate a Sphere shape.
void drawCylinder(float fbaseRadius, float ftopRadius, float fHeight, GLint slices, GLint rings);
							// Used to generate a cylinder shape.

void drawTreeAt(GLfloat x, GLfloat z);
void drawGroundTrees();
void drawBaseAt(GLfloat x); //draw a cube base 

void drawParaBombAt(GLfloat x,GLfloat z);



/////////////////////////////////////////////////////////////////////////

const GLfloat HecLevel = FLOOR_LEVEL + 0.45; //the chopper level
const GLfloat TargLevel = FLOOR_LEVEL + 5; //target level
const GLfloat ExplosionDistance=2.5;

const GLfloat DigitDisplayAngleOffset=5;
const GLfloat DigitDisplayPositionOffset=2;

const GLfloat MaxLatitude=25;
const GLfloat FlyBoundary=FLOOR_SIZE/2-5;
const GLfloat ChopperLength=2.5;
const GLfloat MinLatitude=FLOOR_LEVEL+0.35;
const GLfloat LightOnePitchOffset=-10;
//const GLfloat Flight_Latitude=0.9;
const GLfloat Flight_Latitude=TargLevel;
//const GLfloat Flight_Latitude=HecLevel;

const GLfloat AngleOffset=1;
const GLfloat PositionOffset=0.5;
const GLfloat MovementOffset=0.5;
GLfloat deg2rad(GLfloat deg);
GLfloat rad2deg(GLfloat rad);


struct Movement
{
	GLfloat x,y,z;
	GLfloat yaw, pitch, roll;
};

void initializeMovement();

///////////////////////////////////////////////////////////////////////////

struct Rocket
{
	Movement firePos;
	DWORD fireMoment;
};

////////////////////////////////////////////

const int MaxFragmentCount=9;
const int MaxMissileModelCount=1;


const int MaxSingleBuildingCount=10;
const int MaxExplosionPieces=9;

const int MaxRocketCount=60;
const float RocketFlySpeed=0.01;
const float RocketSize=0.01;
const DWORD MaxRocketFlyTime=6000;

const DWORD MaxFragmentFlyTime=20000;
const float FragmentFlySpeed=0.005;

void drawRockets(DWORD now);
void drawRocket();
bool calcRocket(int index, DWORD now, float &x, float &y, float &z);
void calcCoord(float distance, const Movement& position, float &x, float &y, float &z);
////////////////////////////////////////////////////////////////////////
const int MaxTargetCount=12;
const float TargetMovementSpeed=0.001;
//const float Explosion
struct TargetStruct
{
	int coordIndex;
	int modelIndex;
};








//////////////////////////////////////////////////////////////////////////

#endif
